@@ -1,22 +1,14 @@
 
-# This is the server logic for a Shiny web application.
-# You can find out more about building applications with Shiny here:
-#
-# http://www.rstudio.com/shiny/
-#
-
-
-
 
 shinyServer(function(input, output, session) {
- # library(shiny)
- # library(shinyAce)
- # library(meta)
- # library(metafor)
-  # library(MAd)
-  # library(MAc)
-  # library(quantreg)
-  # library(ggplot2)
+#  library(shiny)
+#  library(shinyAce)
+#  library(meta)
+#  library(metafor)
+#   library(MAd)
+#   library(MAc)
+#   library(quantreg)
+#   library(ggplot2)
   options(warn=-1)
 
 
@@ -68,7 +60,7 @@ shinyServer(function(input, output, session) {
 
     else if (input$type == "cor") {
 
-      dat <- escalc(measure="ZCOR", ni=N, ri=r, data=dat, append=TRUE)
+      dat <- escalc(measure=input$cormeasures, ni=N, ri=r, data=dat, append=TRUE)
       dat$FZ <- dat$yi
       dat$yi <- NULL
       dat$SV <- dat$vi # SV=sampling variances
@@ -128,7 +120,7 @@ shinyServer(function(input, output, session) {
 
       dat <- read.csv(text=input$text, sep="\t")
 
-      dat <- escalc(measure="ZCOR", ni=N, ri=r, data=dat, append=TRUE)
+      dat <- escalc(measure=input$cormeasures, ni=N, ri=r, data=dat, append=TRUE)
       dat$FZ <- dat$yi
       dat$yi <- NULL
       dat$SV <- dat$vi # SV=sampling variances
@@ -188,7 +180,7 @@ shinyServer(function(input, output, session) {
 
       dat <- read.csv(text=input$text, sep="\t")
 
-      dat <- escalc(measure="ZCOR", ni=N, ri=r, data=dat, append=TRUE)
+      dat <- escalc(measure=input$cormeasures, ni=N, ri=r, data=dat, append=TRUE)
       dat$FZ <- dat$yi
       dat$yi <- NULL
       dat$SV <- dat$vi # SV=sampling variances
@@ -255,7 +247,7 @@ shinyServer(function(input, output, session) {
 
     else if (input$type == "cor") {
 
-      dat <- escalc(measure="ZCOR", ni=N, ri=r, data=dat, append=TRUE)
+      dat <- escalc(measure=input$cormeasures, ni=N, ri=r, data=dat, append=TRUE)
       dat$FZ <- round(dat$yi,3)
       dat$yi <- NULL
       dat$SV <- round(dat$vi, 3) # SV=sampling variances
@@ -480,7 +472,7 @@ output$rePlot <- renderPlot(
 
 
 ################################################
-# Funnel plot
+# Funnel plot removed trimfillplot UI input 
 ################################################
 
 makeFunFixPlot <- function(){
@@ -489,7 +481,7 @@ makeFunFixPlot <- function(){
 
     FE.res <- FE.est()$FE.res
 
-    metafor::funnel(trimfill(FE.res))
+    metafor::funnel(trimfill(FE.res, estimator=input$trimfillopt))
 
   }
 
@@ -498,7 +490,7 @@ makeFunFixPlot <- function(){
 
     FE.res <- FE.est()$FE.res
 
-    metafor::funnel(trimfill(FE.res))
+    metafor::funnel(trimfill(FE.res, estimator=input$trimfillopt))
 
   }
 
@@ -507,7 +499,7 @@ makeFunFixPlot <- function(){
 
     FE.res <- FE.est()$FE.res
 
-    metafor::funnel(trimfill(FE.res))
+    metafor::funnel(trimfill(FE.res, estimator=input$trimfillopt))
 
   }
 }
@@ -534,7 +526,7 @@ makeFunRandPlot <- function(){
 
     RE.res <- RE.est()$RE.res
 
-    metafor::funnel(trimfill(RE.res))
+    metafor::funnel(trimfill(RE.res, estimator=input$trimfillopt))
 
   }
 
@@ -543,7 +535,7 @@ makeFunRandPlot <- function(){
 
     RE.res <- RE.est()$RE.res
 
-    metafor::funnel(trimfill(RE.res))
+    metafor::funnel(trimfill(RE.res, estimator=input$trimfillopt))
 
   }
 
@@ -552,7 +544,7 @@ makeFunRandPlot <- function(){
 
     RE.res <- RE.est()$RE.res
 
-    metafor::funnel(trimfill(RE.res))
+    metafor::funnel(trimfill(RE.res, estimator=input$trimfillopt))
 
   }
 }
@@ -572,7 +564,6 @@ output$FunRandPlot <- renderPlot(
 
 
 
-
 ################################################
 # Test of asymmetry & Fail-safe N
 ################################################
@@ -586,8 +577,8 @@ asy <- reactive({
 
     RE.res <- RE.est()$RE.res
 
-    regt <- regtest(RE.res, model="lm")
-    value <- fsn(y = RE.res$yi, v = RE.res$vi)
+    regt <- regtest(RE.res, model="lm", predictor=input$regtestpredictor)
+    value <- fsn(y = RE.res$yi, v = RE.res$vi, type=input$filedraweranalysis)
 
     return(list('No publication bias if p > .05 (Nonsignificant)' = regt,
                 'File drawer analysis' = value))
@@ -598,8 +589,8 @@ asy <- reactive({
 
     RE.res <- RE.est()$RE.res
 
-    regt <- regtest(RE.res, model="lm")
-    value <- fsn(y = RE.res$yi, v = RE.res$vi)
+    regt <- regtest(RE.res, model="lm", predictor=input$regtestpredictor)
+    value <- fsn(y = RE.res$yi, v = RE.res$vi, type=input$filedraweranalysis)
 
     return(list('No publication bias if p > .05 (Nonsignificant)' = regt,
                 'File drawer analysis' = value))
@@ -611,8 +602,8 @@ asy <- reactive({
 
     RE.res <- RE.est()$RE.res
 
-    regt <- regtest(RE.res, model="lm")
-    value <- fsn(y = RE.res$yi, v = RE.res$vi)
+    regt <- regtest(RE.res, model="lm", predictor=input$regtestpredictor)
+    value <- fsn(y = RE.res$yi, v = RE.res$vi, type=input$filedraweranalysis)
 
     return(list('No publication bias if p > .05 (Nonsignificant)' = regt,
                 'File drawer analysis' = value))
@@ -685,7 +676,7 @@ modAnalysis <- reactive({
 
     dat <- read.csv(text=input$text, sep="\t")
 
-    dat <- escalc(measure="ZCOR", ni=N, ri=r, data=dat, append=TRUE)
+    dat <- escalc(measure=input$cormeasures, ni=N, ri=r, data=dat, append=TRUE)
     dat$FZ <- dat$yi
     dat$yi <- NULL
     dat$SV <- dat$vi
@@ -822,10 +813,191 @@ output$ModRandGraph <- renderPlot({
   print(ModRandGraph())
 })
 
+################################################
+# Effect Size Calculators
+################################################
+
+sliderValues <- reactive ({
+  n1 <- as.integer(input$nx)
+  n2 <- as.integer(input$ny)
+  
+  data.frame(
+    n = c(n1, n2),
+    Mean = c(input$mx, input$my),
+    SD = c(input$sdx, input$sdy),
+    stringsAsFactors=FALSE)
+})
+
+difference <- reactive({
+  nx <- input$nx
+  mx <- input$mx
+  sdx <- input$sdx
+  ny <- input$ny
+  my <- input$my
+  sdy <- input$sdy
+  
+  if (input$varequal) {
+    df <- nx+ny-2
+    v <- ((nx-1)*sdx^2+(ny-1)*sdy^2)/df
+    diff <- round((mx - my), 3)
+    diff.std <- sqrt(v * (1/nx + 1/ny))
+    diff.lower <- round(diff + diff.std * qt(0.05/2, df),3)
+    diff.upper <- round(diff + diff.std * qt(0.05/2, df, lower.tail = FALSE),3)
+  } else {
+    stderrx <- sqrt(sdx^2/nx)
+    stderry <- sqrt(sdy^2/ny)
+    stderr <- sqrt(stderrx^2 + stderry^2)
+    df <- round(stderr^4/(stderrx^4/(nx - 1) + stderry^4/(ny - 1)),3)
+    tstat <- round(abs(mx - my)/stderr,3)
+    diff <- round((mx - my), 3)
+    cint <- qt(1 - 0.05/2, df)
+    diff.lower <- round(((tstat - cint) * stderr),3)
+    diff.upper <- round(((tstat + cint) * stderr),3)
+  }
+  
+  cat("Mean of the differences [95% CI] =", diff, "[", diff.lower,",", diff.upper,"]", "\n")
+})
+
+
+es <- reactive({
+  nx <- input$nx
+  mx <- input$mx
+  sdx <- input$sdx
+  ny <- input$ny
+  my <- input$my
+  sdy <- input$sdy
+  
+  mes(mx, my, sdx, sdy, nx, ny)
+})
+
+
+ttest <- reactive({
+  nx <- input$nx
+  mx <- input$mx
+  sdx <- input$sdx
+  ny <- input$ny
+  my <- input$my
+  sdy <- input$sdy
+  
+  if (input$varequal) {
+    df1 <- input$nx+input$ny-2
+    v1 <- ((input$nx-1)*input$sdx^2+(input$ny-1)*input$sdy^2)/df1
+    tstat1 <- round(abs(input$mx-input$my)/sqrt(v1*(1/input$nx+1/input$ny)),3)
+    diff <- round((input$mx - input$my), 3)
+    P1 <- 2 * pt(-abs(tstat1), df1)
+    
+    cat("Independent t-test (equal variances assumed)", "\n",
+        " t =", tstat1, ",", "df =", df1, ",", "p-value =", P1, "\n")
+    
+  } else {
+    
+    stderrx <- sqrt(input$sdx^2/input$nx)
+    stderry <- sqrt(input$sdy^2/input$ny)
+    stderr <- sqrt(stderrx^2 + stderry^2)
+    df2 <- round(stderr^4/(stderrx^4/(input$nx - 1) + stderry^4/(input$ny - 1)),3)
+    tstat2 <- round(abs(input$mx - input$my)/stderr,3)
+    P2 <- 2 * pt(-abs(tstat2), df2)
+    
+    cat("Welch's t-test (equal variances not assumed)", "\n",
+        " t =", tstat2, ",", "df =", df2, ",", "p-value =", P2, "\n")
+  }
+})
+
+
+vartest <- reactive({
+  if (input$vartest) {
+    nx <- input$nx
+    sdx <- input$sdx
+    vx <- sdx^2
+    ny <- input$ny
+    sdy <- input$sdy
+    vy <- sdy^2
+    
+    if (vx > vy) {
+      f <- vx/vy
+      df1 <- nx-1
+      df2 <- ny-1
+    } else {
+      f <- vy/vx
+      df1 <- ny-1
+      df2 <- nx-1
+    }
+    
+    p <- 2*pf(f, df1, df2, lower.tail=FALSE)
+    dfs <- c("num df"=df1, "denom df"=df2)
+    
+    cat(" Test for equality of variances", "\n",
+        "  F =", f, ",", "num df =", df1, ",", "denom df =", df2, "\n",
+        "  p-value = ", p, "\n"
+    )
+    
+  } else {
+    cat("Test for equality of variances will be displayed if the option is selected.")
+  }
+})
 
 
 
 
+# Show the values using an HTML table
+output$values <- renderTable({
+  sliderValues()
+})
+
+# Show the final calculated value
+
+output$difference.out <- renderPrint({
+  difference()
+})
+
+output$es.out <- renderPrint({
+  es()
+})
+
+output$ttest.out <- renderPrint({
+  ttest()
+})
+
+output$vartest.out <- renderPrint({
+  vartest()
+})
+
+################################################
+# Mean Values from ANCOVA F-statistic to Effect Size
+################################################
+
+  a.fesoutput <- reactive({
+    a.fes(input$ancovaf, input$ancovafn1, input$ancovafn2, input$anovafcovar, input$anovafcovarnum)
+   })
+
+  output$ancovaf.out <- renderPrint({
+    a.fesoutput()
+  })
+
+################################################
+# Chi-Squared Statistic to Effect Size
+################################################
+
+  chisquaredes <- reactive({
+     chies(input$chisquaredstat, input$chisquaredn1)
+  })
+
+  output$chisquared.out <- renderPrint({
+    chisquaredes()
+  })
+
+################################################
+# p-value to Effect Size
+################################################
+
+pvaluees <- reactive({
+  pes(input$pvaluenum, input$pvaluen1, input$pvaluen2, tail = input$pvaluetail)
+})
+
+output$pvaluees.out <- renderPrint({
+  pvaluees()
+})
+
 ################################################
 # R session info
 ################################################
@@ -867,6 +1039,14 @@ info <- reactive({
 ################################################
 output$model.out <- renderPrint({ input$model })
 
+output$cormeasures.out <- renderPrint({ input$cormeasures })
+
+output$trimfillopt.out <- renderPrint({paste("Selected method is:", input$trimfillopt )})
+
+output$regtestpredictor.out <- renderPrint({paste("Selected predictor is:", input$regtestpredictor )})
+
+output$filedraweranalysis.out <- renderPrint({ paste("Selected method is:", input$filedraweranalysis) })
+
 output$height.out <- renderPrint({paste(input$height,"px", sep ="")})
 
 output$info.out <- renderPrint({
@@ -936,3 +1116,25 @@ output$downloadFunRandPlot <- downloadHandler(
   }
 )
 })
+
+#            *     ,MMM8&&&.            *
+#                  MMMM88&&&&&    .
+#                 MMMM88&&&&&&&
+#     *           MMM88&&&&&&&&
+#                 MMM88&&&&&&&&
+#                 'MMM88&&&&&&'
+#                   'MMM8&&&'      *    
+#          |\___/|     /\___/\
+#          )     (     )    ~( .              '
+#         =\     /=   =\~    /=
+#           )===(       ) ~ (
+#          /     \     /     \
+#          |     |     ) ~   (
+#         /       \   /     ~ \
+#         \       /   \~     ~/
+#  jgs_/\_/\__  _/_/\_/\__~__/_/\_/\_/\_/\_/\_
+#  |  |  |  |( (  |  |  | ))  |  |  |  |  |  |
+#  |  |  |  | ) ) |  |  |//|  |  |  |  |  |  |
+#  |  |  |  |(_(  |  |  (( |  |  |  |  |  |  |
+#  |  |  |  |  |  |  |  |\)|  |  |  |  |  |  |
+#  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
